RDS — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »

# RDS

## boto.rds

class `boto.rds.` `RDSConnection`(aws_access_key_id=None, aws_secret_access_key=None, is_secure=True, port=None, proxy=None, proxy_port=None, proxy_user=None, proxy_pass=None, debug=0, https_connection_factory=None, region=None, path='/', security_token=None, validate_certs=True, profile_name=None)
  `APIVersion` = '2013-05-15'
  `DefaultRegionEndpoint` = 'rds.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `authorize_dbsecurity_group`(group_name, cidr_ip=None, ec2_security_group_name=None, ec2_security_group_owner_id=None)

    Add a new rule to an existing security group. You need to pass in either src_security_group_name and src_security_group_owner_id OR a CIDR block but not both.

    Parameters: | group_name (string) – The name of the security group you are adding the rule to. ec2_security_group_name (string) – The name of the EC2 security group you are granting access to. ec2_security_group_owner_id (string) – The ID of the owner of the EC2 security group you are granting access to. cidr_ip (string) – The CIDR block you are providing access to. See http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing
    Return type: | bool
    Returns: | True if successful.

  `copy_dbsnapshot`(source_snapshot_id, target_snapshot_id)

    Copies the specified DBSnapshot.

    Parameters: | source_snapshot_id (string) – The identifier for the source DB snapshot. target_snapshot_id (string) – The identifier for the copied snapshot.
    Return type: | `boto.rds.dbsnapshot.DBSnapshot`
    Returns: | The newly created DBSnapshot.

  `create_db_subnet_group`(name, desc, subnet_ids)

    Create a new Database Subnet Group.

    Parameters: | name (string) – The identifier for the db_subnet_group desc (string) – A description of the db_subnet_group subnets – A list of the subnet identifiers to include in the db_subnet_group
    Return type: | :class:`boto.rds.dbsubnetgroup.DBSubnetGroup
    Returns: | the created db_subnet_group

  `create_dbinstance`(id, allocated_storage, instance_class, master_username, master_password, port=3306, engine='MySQL5.1', db_name=None, param_group=None, security_groups=None, availability_zone=None, preferred_maintenance_window=None, backup_retention_period=None, preferred_backup_window=None, multi_az=False, engine_version=None, auto_minor_version_upgrade=True, character_set_name=None, db_subnet_group_name=None, license_model=None, option_group_name=None, iops=None, vpc_security_groups=None)

    Create a new DBInstance.

    Parameters: | id (str) – Unique identifier for the new instance. Must contain 1-63 alphanumeric characters. First character must be a letter. May not end with a hyphen or contain two consecutive hyphens allocated_storage (int) – Initially allocated storage size, in GBs. Valid values are depending on the engine value. MySQL = 5–3072 oracle-se1 = 10–3072 oracle-se = 10–3072 oracle-ee = 10–3072 sqlserver-ee = 200–1024 sqlserver-se = 200–1024 sqlserver-ex = 30–1024 sqlserver-web = 30–1024 postgres = 5–3072 instance_class (str) – The compute and memory capacity of the DBInstance. Valid values are: db.t1.micro db.m1.small db.m1.medium db.m1.large db.m1.xlarge db.m2.xlarge db.m2.2xlarge db.m2.4xlarge engine (str) – Name of database engine. Defaults to MySQL but can be; MySQL oracle-se1 oracle-se oracle-ee sqlserver-ee sqlserver-se sqlserver-ex sqlserver-web postgres master_username (str) – Name of master user for the DBInstance. MySQL must be; - 1–16 alphanumeric characters - first character must be a letter - cannot be a reserved MySQL word Oracle must be: - 1–30 alphanumeric characters - first character must be a letter - cannot be a reserved Oracle word SQL Server must be: - 1–128 alphanumeric characters - first character must be a letter - cannot be a reserver SQL Server word master_password (str) – Password of master user for the DBInstance. MySQL must be 8–41 alphanumeric characters Oracle must be 8–30 alphanumeric characters SQL Server must be 8–128 alphanumeric characters. port (int) – Port number on which database accepts connections. Valid values [1115-65535]. MySQL defaults to 3306 Oracle defaults to 1521 SQL Server defaults to 1433 and _cannot_ be 1434, 3389, 47001, 49152, and 49152 through 49156. PostgreSQL defaults to 5432 db_name (str) – MySQL: Name of a database to create when the DBInstance is created. Default is to create no databases. Must contain 1–64 alphanumeric characters and cannot be a reserved MySQL word. Oracle: The Oracle System ID (SID) of the created DB instances. Default is ORCL. Cannot be longer than 8 characters. SQL Server: Not applicable and must be None. PostgreSQL: Name of a database to create when the DBInstance is created. Default is to create no databases. Must contain 1–63 alphanumeric characters. Must begin with a letter or an underscore. Subsequent characters can be letters, underscores, or digits (0-9) and cannot be a reserved PostgreSQL word. param_group (str or ParameterGroup object) – Name of DBParameterGroup or ParameterGroup instance to associate with this DBInstance. If no groups are specified no parameter groups will be used. security_groups (list of str or list of DBSecurityGroup objects) – List of names of DBSecurityGroup to authorize on this DBInstance. availability_zone (str) – Name of the availability zone to place DBInstance into. preferred_maintenance_window (str) – The weekly time range (in UTC) during which maintenance can occur. Default is Sun:05:00-Sun:09:00 backup_retention_period (int) – The number of days for which automated backups are retained. Setting this to zero disables automated backups. preferred_backup_window (str) – The daily time range during which automated backups are created (if enabled). Must be in h24:mi-hh24:mi format (UTC). multi_az (bool) – If True, specifies the DB Instance will be deployed in multiple availability zones. For Microsoft SQL Server, must be set to false. You cannot set the AvailabilityZone parameter if the MultiAZ parameter is set to true. engine_version (str) – The version number of the database engine to use. MySQL format example: 5.1.42 Oracle format example: 11.2.0.2.v2 SQL Server format example: 10.50.2789.0.v1 PostgreSQL format example: 9.3 auto_minor_version_upgrade (bool) – Indicates that minor engine upgrades will be applied automatically to the Read Replica during the maintenance window. Default is True. character_set_name (str) – For supported engines, indicates that the DB Instance should be associated with the specified CharacterSet. db_subnet_group_name (str) – A DB Subnet Group to associate with this DB Instance. If there is no DB Subnet Group, then it is a non-VPC DB instance. license_model (str) – License model information for this DB Instance. Valid values are; - license-included - bring-your-own-license - general-public-license All license types are not supported on all engines. option_group_name (str) – Indicates that the DB Instance should be associated with the specified option group. iops (int) – The amount of IOPS (input/output operations per second) to Provisioned for the DB Instance. Can be modified at a later date. Must scale linearly. For every 1000 IOPS provision, you must allocated 100 GB of storage space. This scales up to 1 TB / 10 000 IOPS for MySQL and Oracle. MSSQL is limited to 700 GB / 7 000 IOPS. If you specify a value, it must be at least 1000 IOPS and you must allocate 100 GB of storage. vpc_security_groups (list of str or a VPCSecurityGroupMembership object) – List of VPC security group ids or a list of VPCSecurityGroupMembership objects this DBInstance should be a member of
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The new db instance.

  `create_dbinstance_read_replica`(id, source_id, instance_class=None, port=3306, availability_zone=None, auto_minor_version_upgrade=None)

    Create a new DBInstance Read Replica.

    Parameters: | id (str) – Unique identifier for the new instance. Must contain 1-63 alphanumeric characters. First character must be a letter. May not end with a hyphen or contain two consecutive hyphens source_id (str) – Unique identifier for the DB Instance for which this DB Instance will act as a Read Replica. instance_class (str) – The compute and memory capacity of the DBInstance. Default is to inherit from the source DB Instance. Valid values are: db.m1.small db.m1.large db.m1.xlarge db.m2.xlarge db.m2.2xlarge db.m2.4xlarge port (int) – Port number on which database accepts connections. Default is to inherit from source DB Instance. Valid values [1115-65535]. Defaults to 3306. availability_zone (str) – Name of the availability zone to place DBInstance into. auto_minor_version_upgrade (bool) – Indicates that minor engine upgrades will be applied automatically to the Read Replica during the maintenance window. Default is to inherit this value from the source DB Instance.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The new db instance.

  `create_dbsecurity_group`(name, description=None)

    Create a new security group for your account. This will create the security group within the region you are currently connected to.

    Parameters: | name (string) – The name of the new security group description (string) – The description of the new security group
    Return type: | `boto.rds.dbsecuritygroup.DBSecurityGroup`
    Returns: | The newly created DBSecurityGroup

  `create_dbsnapshot`(snapshot_id, dbinstance_id)

    Create a new DB snapshot.

    Parameters: | snapshot_id (string) – The identifier for the DBSnapshot dbinstance_id (string) – The source identifier for the RDS instance from which the snapshot is created.
    Return type: | `boto.rds.dbsnapshot.DBSnapshot`
    Returns: | The newly created DBSnapshot

  `create_option_group`(name, engine_name, major_engine_version, description=None)

    Create a new option group for your account. This will create the option group within the region you are currently connected to.

    Parameters: | name (string) – The name of the new option group engine_name (string) – Specifies the name of the engine that this option group should be associated with. major_engine_version (string) – Specifies the major version of the engine that this option group should be associated with. description (string) – The description of the new option group
    Return type: | `boto.rds.optiongroup.OptionGroup`
    Returns: | The newly created OptionGroup

  `create_parameter_group`(name, engine='MySQL5.1', description='')

    Create a new dbparameter group for your account.

    Parameters: | name (string) – The name of the new dbparameter group engine (str) – Name of database engine. description (string) – The description of the new dbparameter group
    Return type: | `boto.rds.parametergroup.ParameterGroup`
    Returns: | The newly created ParameterGroup

  `delete_db_subnet_group`(name)

    Delete a Database Subnet Group.

    Parameters: | name (string) – The identifier of the db_subnet_group to delete
    Return type: | `boto.rds.dbsubnetgroup.DBSubnetGroup`
    Returns: | The deleted db_subnet_group.

  `delete_dbinstance`(id, skip_final_snapshot=False, final_snapshot_id='')

    Delete an existing DBInstance.

    Parameters: | id (str) – Unique identifier for the new instance. skip_final_snapshot (bool) – This parameter determines whether a final db snapshot is created before the instance is deleted. If True, no snapshot is created. If False, a snapshot is created before deleting the instance. final_snapshot_id (str) – If a final snapshot is requested, this is the identifier used for that snapshot.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The deleted db instance.

  `delete_dbsecurity_group`(name)

    Delete a DBSecurityGroup from your account.

    Parameters: | key_name (string) – The name of the DBSecurityGroup to delete

  `delete_dbsnapshot`(identifier)

    Delete a DBSnapshot

    Parameters: | identifier (string) – The identifier of the DBSnapshot to delete

  `delete_option_group`(name)

    Delete an OptionGroup from your account.

    Parameters: | key_name (string) – The name of the OptionGroup to delete

  `delete_parameter_group`(name)

    Delete a ParameterGroup from your account.

    Parameters: | key_name (string) – The name of the ParameterGroup to delete

  `describe_option_group_options`(engine_name=None, major_engine_version=None, max_records=100, marker=None)

    Describes the available option group options.

    Parameters: | engine_name (str) – Filters the list of option groups to only include groups associated with a specific database engine. major_engine_version (datetime) – Filters the list of option groups to only include groups associated with a specific database engine version. If specified, then engine_name must also be specified. max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of class:boto.rds.optiongroup.Option

  `describe_option_groups`(name=None, engine_name=None, major_engine_version=None, max_records=100, marker=None)

    Describes the available option groups.

    Parameters: | name (str) – The name of the option group to describe. Cannot be supplied together with engine_name or major_engine_version. engine_name (str) – Filters the list of option groups to only include groups associated with a specific database engine. major_engine_version (datetime) – Filters the list of option groups to only include groups associated with a specific database engine version. If specified, then engine_name must also be specified. max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of class:boto.rds.optiongroup.OptionGroup

  `get_all_db_subnet_groups`(name=None, max_records=None, marker=None)

    Retrieve all the DBSubnetGroups in your account.

    Parameters: | name (str) – DBSubnetGroup name If supplied, only information about this DBSubnetGroup will be returned. Otherwise, info about all DBSubnetGroups will be returned. max_records (int) – The maximum number of records to be returned. If more results are available, a Token will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of `boto.rds.dbsubnetgroup.DBSubnetGroup`

  `get_all_dbinstances`(instance_id=None, max_records=None, marker=None)

    Retrieve all the DBInstances in your account.

    Parameters: | instance_id (str) – DB Instance identifier. If supplied, only information this instance will be returned. Otherwise, info about all DB Instances will be returned. max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of `boto.rds.dbinstance.DBInstance`

  `get_all_dbparameter_groups`(groupname=None, max_records=None, marker=None)

    Get all parameter groups associated with your account in a region.

    Parameters: | groupname (str) – The name of the DBParameter group to retrieve. If not provided, all DBParameter groups will be returned. max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of `boto.ec2.parametergroup.ParameterGroup`

  `get_all_dbparameters`(groupname, source=None, max_records=None, marker=None)

    Get all parameters associated with a ParameterGroup

    Parameters: | groupname (str) – The name of the DBParameter group to retrieve. source (str) – Specifies which parameters to return. If not specified, all parameters will be returned. Valid values are: user|system|engine-default max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | `boto.ec2.parametergroup.ParameterGroup`
    Returns: | The ParameterGroup

  `get_all_dbsecurity_groups`(groupname=None, max_records=None, marker=None)

    Get all security groups associated with your account in a region.

    Parameters: | groupnames (list) – A list of the names of security groups to retrieve. If not provided, all security groups will be returned. max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of `boto.rds.dbsecuritygroup.DBSecurityGroup`

  `get_all_dbsnapshots`(snapshot_id=None, instance_id=None, max_records=None, marker=None)

    Get information about DB Snapshots.

    Parameters: | snapshot_id (str) – The unique identifier of an RDS snapshot. If not provided, all RDS snapshots will be returned. instance_id (str) – The identifier of a DBInstance. If provided, only the DBSnapshots related to that instance will be returned. If not provided, all RDS snapshots will be returned. max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of `boto.rds.dbsnapshot.DBSnapshot`

  `get_all_events`(source_identifier=None, source_type=None, start_time=None, end_time=None, max_records=None, marker=None)

    Get information about events related to your DBInstances, DBSecurityGroups and DBParameterGroups.

    Parameters: | source_identifier (str) – If supplied, the events returned will be limited to those that apply to the identified source. The value of this parameter depends on the value of source_type. If neither parameter is specified, all events in the time span will be returned. source_type (str) – Specifies how the source_identifier should be interpreted. Valid values are: b-instance | db-security-group | db-parameter-group | db-snapshot start_time (datetime) – The beginning of the time interval for events. If not supplied, all available events will be returned. end_time (datetime) – The ending of the time interval for events. If not supplied, all available events will be returned. max_records (int) – The maximum number of records to be returned. If more results are available, a MoreToken will be returned in the response that can be used to retrieve additional records. Default is 100. marker (str) – The marker provided by a previous request.
    Return type: | list
    Returns: | A list of class:boto.rds.event.Event

  `get_all_logs`(dbinstance_id=None)

    Get all log files

    Parameters: | instance_id (str) – The identifier of a DBInstance. If provided, only the `boto.rds.logfile.LogFile` related to that instance will be returned. If not provided, all logfiles will be returned.
    Return type: | list
    Returns: | A list of `boto.rds.logfile.LogFile`

  `modify_db_subnet_group`(name, description=None, subnet_ids=None)

    Modify a parameter group for your account.

    Parameters: | name (string) – The name of the new parameter group parameters (list of `boto.rds.parametergroup.Parameter`) – The new parameters
    Return type: | `boto.rds.parametergroup.ParameterGroup`
    Returns: | The newly created ParameterGroup

  `modify_dbinstance`(id, param_group=None, security_groups=None, preferred_maintenance_window=None, master_password=None, allocated_storage=None, instance_class=None, backup_retention_period=None, preferred_backup_window=None, multi_az=False, apply_immediately=False, iops=None, vpc_security_groups=None, new_instance_id=None)

    Modify an existing DBInstance.

    Parameters: | id (str) – Unique identifier for the new instance. param_group (str or ParameterGroup object) – Name of DBParameterGroup or ParameterGroup instance to associate with this DBInstance. If no groups are specified no parameter groups will be used. security_groups (list of str or list of DBSecurityGroup objects) – List of names of DBSecurityGroup to authorize on this DBInstance. preferred_maintenance_window (str) – The weekly time range (in UTC) during which maintenance can occur. Default is Sun:05:00-Sun:09:00 master_password (str) – Password of master user for the DBInstance. Must be 4-15 alphanumeric characters. allocated_storage (int) – The new allocated storage size, in GBs. Valid values are [5-1024] instance_class (str) – The compute and memory capacity of the DBInstance. Changes will be applied at next maintenance window unless apply_immediately is True. Valid values are: db.m1.small db.m1.large db.m1.xlarge db.m2.xlarge db.m2.2xlarge db.m2.4xlarge apply_immediately (bool) – If true, the modifications will be applied as soon as possible rather than waiting for the next preferred maintenance window. backup_retention_period (int) – The number of days for which automated backups are retained. Setting this to zero disables automated backups. preferred_backup_window (str) – The daily time range during which automated backups are created (if enabled). Must be in h24:mi-hh24:mi format (UTC). multi_az (bool) – If True, specifies the DB Instance will be deployed in multiple availability zones. iops (int) – The amount of IOPS (input/output operations per second) to Provisioned for the DB Instance. Can be modified at a later date. Must scale linearly. For every 1000 IOPS provision, you must allocated 100 GB of storage space. This scales up to 1 TB / 10 000 IOPS for MySQL and Oracle. MSSQL is limited to 700 GB / 7 000 IOPS. If you specify a value, it must be at least 1000 IOPS and you must allocate 100 GB of storage. vpc_security_groups (list of str or a VPCSecurityGroupMembership object) – List of VPC security group ids or a VPCSecurityGroupMembership object this DBInstance should be a member of new_instance_id (str) – New name to rename the DBInstance to.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The modified db instance.

  `modify_parameter_group`(name, parameters=None)

    Modify a ParameterGroup for your account.

    Parameters: | name (string) – The name of the new ParameterGroup parameters (list of `boto.rds.parametergroup.Parameter`) – The new parameters
    Return type: | `boto.rds.parametergroup.ParameterGroup`
    Returns: | The newly created ParameterGroup

  `promote_read_replica`(id, backup_retention_period=None, preferred_backup_window=None)

    Promote a Read Replica to a standalone DB Instance.

    Parameters: | id (str) – Unique identifier for the new instance. Must contain 1-63 alphanumeric characters. First character must be a letter. May not end with a hyphen or contain two consecutive hyphens backup_retention_period (int) – The number of days for which automated backups are retained. Setting this to zero disables automated backups. preferred_backup_window (str) – The daily time range during which automated backups are created (if enabled). Must be in h24:mi-hh24:mi format (UTC).
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The new db instance.

  `reboot_dbinstance`(id)

    Reboot DBInstance.

    Parameters: | id (str) – Unique identifier of the instance.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The rebooting db instance.

  `reset_parameter_group`(name, reset_all_params=False, parameters=None)

    Resets some or all of the parameters of a ParameterGroup to the default value

    Parameters: | key_name (string) – The name of the ParameterGroup to reset parameters (list of `boto.rds.parametergroup.Parameter`) – The parameters to reset. If not supplied, all parameters will be reset.

  `restore_dbinstance_from_dbsnapshot`(identifier, instance_id, instance_class, port=None, availability_zone=None, multi_az=None, auto_minor_version_upgrade=None, db_subnet_group_name=None)

    Create a new DBInstance from a DB snapshot.

    Parameters: | identifier (string) – The identifier for the DBSnapshot instance_id (string) – The source identifier for the RDS instance from which the snapshot is created. instance_class (str) – The compute and memory capacity of the DBInstance. Valid values are: db.m1.small | db.m1.large | db.m1.xlarge | db.m2.2xlarge | db.m2.4xlarge port (int) – Port number on which database accepts connections. Valid values [1115-65535]. Defaults to 3306. availability_zone (str) – Name of the availability zone to place DBInstance into. multi_az (bool) – If True, specifies the DB Instance will be deployed in multiple availability zones. Default is the API default. auto_minor_version_upgrade (bool) – Indicates that minor engine upgrades will be applied automatically to the Read Replica during the maintenance window. Default is the API default. db_subnet_group_name (str) – A DB Subnet Group to associate with this DB Instance. If there is no DB Subnet Group, then it is a non-VPC DB instance.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The newly created DBInstance

  `restore_dbinstance_from_point_in_time`(source_instance_id, target_instance_id, use_latest=False, restore_time=None, dbinstance_class=None, port=None, availability_zone=None, db_subnet_group_name=None)

    Create a new DBInstance from a point in time.

    Parameters: | source_instance_id (string) – The identifier for the source DBInstance. target_instance_id (string) – The identifier of the new DBInstance. use_latest (bool) – If True, the latest snapshot availabile will be used. restore_time (datetime) – The date and time to restore from. Only used if use_latest is False. instance_class (str) – The compute and memory capacity of the DBInstance. Valid values are: db.m1.small | db.m1.large | db.m1.xlarge | db.m2.2xlarge | db.m2.4xlarge port (int) – Port number on which database accepts connections. Valid values [1115-65535]. Defaults to 3306. availability_zone (str) – Name of the availability zone to place DBInstance into. db_subnet_group_name (str) – A DB Subnet Group to associate with this DB Instance. If there is no DB Subnet Group, then it is a non-VPC DB instance.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The newly created DBInstance

  `revoke_dbsecurity_group`(group_name, ec2_security_group_name=None, ec2_security_group_owner_id=None, cidr_ip=None)

    Remove an existing rule from an existing security group. You need to pass in either ec2_security_group_name and ec2_security_group_owner_id OR a CIDR block.

    Parameters: | group_name (string) – The name of the security group you are removing the rule from. ec2_security_group_name (string) – The name of the EC2 security group from which you are removing access. ec2_security_group_owner_id (string) – The ID of the owner of the EC2 security from which you are removing access. cidr_ip (string) – The CIDR block from which you are removing access. See http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing
    Return type: | bool
    Returns: | True if successful.

  `revoke_security_group`(group_name, ec2_security_group_name=None, ec2_security_group_owner_id=None, cidr_ip=None)

    Remove an existing rule from an existing security group. You need to pass in either ec2_security_group_name and ec2_security_group_owner_id OR a CIDR block.

    Parameters: | group_name (string) – The name of the security group you are removing the rule from. ec2_security_group_name (string) – The name of the EC2 security group from which you are removing access. ec2_security_group_owner_id (string) – The ID of the owner of the EC2 security from which you are removing access. cidr_ip (string) – The CIDR block from which you are removing access. See http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing
    Return type: | bool
    Returns: | True if successful.

`boto.rds.` `connect_to_region`(region_name, **kw_params)

  Given a valid region name, return a `boto.rds.RDSConnection`. Any additional parameters after the region_name are passed on to the connect method of the region object.

  Type : | str
  Parameters: | region_name – The name of the region to connect to.
  Return type: | `boto.rds.RDSConnection` or `None`
  Returns: | A connection to the given region, or None if an invalid region name is given

`boto.rds.` `regions`()

  Get all available regions for the RDS service.

  Return type: | list
  Returns: | A list of `boto.rds.regioninfo.RDSRegionInfo`

## boto.rds.dbinstance

class `boto.rds.dbinstance.` `DBInstance`(connection=None, id=None)

  Represents a RDS DBInstance

  Properties reference available from the AWS documentation at http://goo.gl/sC2Kn

  Variables: | connection – connection id – The name and identifier of the DBInstance create_time – The date and time of creation engine – The database engine being used status – The status of the database in a string. e.g. “available” allocated_storage – The size of the disk in gigabytes (int). auto_minor_version_upgrade – Indicates that minor version patches are applied automatically. endpoint – A tuple that describes the hostname and port of the instance. This is only available when the database is in status “available”. instance_class – Contains the name of the compute and memory capacity class of the DB Instance. master_username – The username that is set as master username at creation time. parameter_groups – Provides the list of DB Parameter Groups applied to this DB Instance. security_groups – Provides List of DB Security Group elements containing only DBSecurityGroup.Name and DBSecurityGroup.Status subelements. availability_zone – Specifies the name of the Availability Zone the DB Instance is located in. backup_retention_period – Specifies the number of days for which automatic DB Snapshots are retained. preferred_backup_window – Specifies the daily time range during which automated backups are created if automated backups are enabled, as determined by the backup_retention_period. preferred_maintenance_window – Specifies the weekly time range (in UTC) during which system maintenance can occur. (string) latest_restorable_time – Specifies the latest time to which a database can be restored with point-in-time restore. (string) multi_az – Boolean that specifies if the DB Instance is a Multi-AZ deployment. iops – The current number of provisioned IOPS for the DB Instance. Can be None if this is a standard instance. vpc_security_groups – List of VPC Security Group Membership elements containing only VpcSecurityGroupMembership.VpcSecurityGroupId and VpcSecurityGroupMembership.Status subelements. pending_modified_values – Specifies that changes to the DB Instance are pending. This element is only included when changes are pending. Specific changes are identified by subelements. read_replica_dbinstance_identifiers – List of read replicas associated with this DB instance. status_infos – The status of a Read Replica. If the instance is not a for a read replica, this will be blank. character_set_name – If present, specifies the name of the character set that this instance is associated with. subnet_group – Specifies information on the subnet group associated with the DB instance, including the name, description, and subnets in the subnet group. engine_version – Indicates the database engine version. license_model – License model information for this DB instance.

  `endElement`(name, value, connection)
  `modify`(param_group=None, security_groups=None, preferred_maintenance_window=None, master_password=None, allocated_storage=None, instance_class=None, backup_retention_period=None, preferred_backup_window=None, multi_az=False, iops=None, vpc_security_groups=None, apply_immediately=False, new_instance_id=None)

    Modify this DBInstance.

    Parameters: | param_group (str) – Name of DBParameterGroup to associate with this DBInstance. security_groups (list of str or list of DBSecurityGroup objects) – List of names of DBSecurityGroup to authorize on this DBInstance. preferred_maintenance_window (str) – The weekly time range (in UTC) during which maintenance can occur. Default is Sun:05:00-Sun:09:00 master_password (str) – Password of master user for the DBInstance. Must be 4-15 alphanumeric characters. allocated_storage (int) – The new allocated storage size, in GBs. Valid values are [5-1024] instance_class (str) – The compute and memory capacity of the DBInstance. Changes will be applied at next maintenance window unless apply_immediately is True. Valid values are: db.m1.small db.m1.large db.m1.xlarge db.m2.xlarge db.m2.2xlarge db.m2.4xlarge apply_immediately (bool) – If true, the modifications will be applied as soon as possible rather than waiting for the next preferred maintenance window. new_instance_id (str) – The new DB instance identifier. backup_retention_period (int) – The number of days for which automated backups are retained. Setting this to zero disables automated backups. preferred_backup_window (str) – The daily time range during which automated backups are created (if enabled). Must be in h24:mi-hh24:mi format (UTC). multi_az (bool) – If True, specifies the DB Instance will be deployed in multiple availability zones. iops (int) – The amount of IOPS (input/output operations per second) to Provisioned for the DB Instance. Can be modified at a later date. Must scale linearly. For every 1000 IOPS provision, you must allocated 100 GB of storage space. This scales up to 1 TB / 10 000 IOPS for MySQL and Oracle. MSSQL is limited to 700 GB / 7 000 IOPS. If you specify a value, it must be at least 1000 IOPS and you must allocate 100 GB of storage. vpc_security_groups (list) – List of VPCSecurityGroupMembership that this DBInstance is a memberof.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The modified db instance.

  `parameter_group`

    Provide backward compatibility for previous parameter_group attribute.

  `reboot`()

    Reboot this DBInstance

    Return type: | `boto.rds.dbsnapshot.DBSnapshot`
    Returns: | The newly created DBSnapshot

  `security_group`

    Provide backward compatibility for previous security_group attribute.

  `snapshot`(snapshot_id)

    Create a new DB snapshot of this DBInstance.

    Parameters: | identifier (string) – The identifier for the DBSnapshot
    Return type: | `boto.rds.dbsnapshot.DBSnapshot`
    Returns: | The newly created DBSnapshot

  `startElement`(name, attrs, connection)
  `stop`(skip_final_snapshot=False, final_snapshot_id='')

    Delete this DBInstance.

    Parameters: | skip_final_snapshot (bool) – This parameter determines whether a final db snapshot is created before the instance is deleted. If True, no snapshot is created. If False, a snapshot is created before deleting the instance. final_snapshot_id (str) – If a final snapshot is requested, this is the identifier used for that snapshot.
    Return type: | `boto.rds.dbinstance.DBInstance`
    Returns: | The deleted db instance.

  `update`(validate=False)

    Update the DB instance’s status information by making a call to fetch the current instance attributes from the service.

    Parameters: | validate (bool) – By default, if EC2 returns no data about the instance the update method returns quietly. If the validate param is True, however, it will raise a ValueError exception if no data is returned from EC2.

class `boto.rds.dbinstance.` `PendingModifiedValues`
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.rds.dbinstance.` `ReadReplicaDBInstanceIdentifiers`
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

## boto.rds.dbsecuritygroup

Represents an DBSecurityGroup

class `boto.rds.dbsecuritygroup.` `DBSecurityGroup`(connection=None, owner_id=None, name=None, description=None)

  Represents an RDS database security group

  Properties reference available from the AWS documentation at http://docs.amazonwebservices.com/AmazonRDS/latest/APIReference/API_DeleteDBSecurityGroup.html

  Variables: | Status – The current status of the security group. Possible values are [ active, ? ]. Reference documentation lacks specifics of possibilities connection – `boto.rds.RDSConnection` associated with the current object description – The description of the security group ec2_groups – List of `EC2 Security Group` objects that this security group PERMITS ip_ranges – List of `boto.rds.dbsecuritygroup.IPRange` objects (containing CIDR addresses) that this security group PERMITS name – Name of the security group owner_id – ID of the owner of the security group. Can be ‘None’

  `authorize`(cidr_ip=None, ec2_group=None)

    Add a new rule to this DBSecurity group. You need to pass in either a CIDR block to authorize or and EC2 SecurityGroup.

    Parameters: | cidr_ip (string) – A valid CIDR IP range to authorize ec2_group (`boto.ec2.securitygroup.SecurityGroup`) – An EC2 security group to authorize
    Return type: | bool
    Returns: | True if successful.

  `delete`()
  `endElement`(name, value, connection)
  `revoke`(cidr_ip=None, ec2_group=None)

    Revoke access to a CIDR range or EC2 SecurityGroup. You need to pass in either a CIDR block or an EC2 SecurityGroup from which to revoke access.

    Parameters: | cidr_ip (string) – A valid CIDR IP range to revoke ec2_group (`boto.ec2.securitygroup.SecurityGroup`) – An EC2 security group to revoke
    Return type: | bool
    Returns: | True if successful.

  `startElement`(name, attrs, connection)

class `boto.rds.dbsecuritygroup.` `EC2SecurityGroup`(parent=None)

  Describes an EC2 security group for use in a DBSecurityGroup

  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.rds.dbsecuritygroup.` `IPRange`(parent=None)

  Describes a CIDR address range for use in a DBSecurityGroup

  Variables: | cidr_ip – IP Address range

  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

## boto.rds.dbsnapshot

class `boto.rds.dbsnapshot.` `DBSnapshot`(connection=None, id=None)

  Represents a RDS DB Snapshot

  Properties reference available from the AWS documentation at http://docs.amazonwebservices.com/AmazonRDS/latest/APIReference/API_DBSnapshot.html

  Variables: | engine_version – Specifies the version of the database engine license_model – License model information for the restored DB instance allocated_storage – Specifies the allocated storage size in gigabytes (GB) availability_zone – Specifies the name of the Availability Zone the DB Instance was located in at the time of the DB Snapshot connection – boto.rds.RDSConnection associated with the current object engine – Specifies the name of the database engine id – Specifies the identifier for the DB Snapshot (DBSnapshotIdentifier) instance_create_time – Specifies the time (UTC) when the snapshot was taken instance_id – Specifies the the DBInstanceIdentifier of the DB Instance this DB Snapshot was created from (DBInstanceIdentifier) master_username – Provides the master username for the DB Instance port – Specifies the port that the database engine was listening on at the time of the snapshot snapshot_create_time – Provides the time (UTC) when the snapshot was taken status – Specifies the status of this DB Snapshot. Possible values are [ available, backing-up, creating, deleted, deleting, failed, modifying, rebooting, resetting-master-credentials ] iops – Specifies the Provisioned IOPS (I/O operations per second) value of the DB instance at the time of the snapshot. option_group_name – Provides the option group name for the DB snapshot. percent_progress – The percentage of the estimated data that has been transferred. snapshot_type – Provides the type of the DB snapshot. source_region – The region that the DB snapshot was created in or copied from. vpc_id – Provides the Vpc Id associated with the DB snapshot.

  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)
  `update`(validate=False)

    Update the DB snapshot’s status information by making a call to fetch the current snapshot attributes from the service.

    Parameters: | validate (bool) – By default, if EC2 returns no data about the instance the update method returns quietly. If the validate param is True, however, it will raise a ValueError exception if no data is returned from EC2.

## boto.rds.event

class `boto.rds.event.` `Event`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

## boto.rds.parametergroup

class `boto.rds.parametergroup.` `Parameter`(group=None, name=None)

  Represents a RDS Parameter

  `ValidApplyMethods` = ['immediate', 'pending-reboot']
  `ValidApplyTypes` = ['static', 'dynamic']
  `ValidSources` = ['user', 'system', 'engine-default']
  `ValidTypes` = {'integer': <type 'int'>, 'boolean': <type 'bool'>, 'string': <type 'str'>}
  `apply`(immediate=False)
  `endElement`(name, value, connection)
  `get_value`()
  `merge`(d, i)
  `set_value`(value)
  `startElement`(name, attrs, connection)
  `value`

class `boto.rds.parametergroup.` `ParameterGroup`(connection=None)
  `add_param`(name, value, apply_method)
  `endElement`(name, value, connection)
  `get_params`()
  `modifiable`()
  `startElement`(name, attrs, connection)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »